%define anolis_release 4
%bcond_with pandoc
%bcond_with static
%bcond_without pyverbs

Name:    rdma-core
Version: 44.0
Release: %{anolis_release}%{?dist}
Summary: RDMA core userspace libraries and daemons
License: GPLv2 or BSD
Url:     https://github.com/linux-rdma/rdma-core
Source0: %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz

# https://github.com/linux-rdma/rdma-core/pull/1308
Patch1: 0001-util-fix-overflow-in-remap_node_name.patch
Patch2: 0002-infiniband-diags-drop-unnecessary-nodedesc-local-cop.patch
Patch3: 0003-libibnetdisc-fix-printing-a-possibly-non-NUL-termina.patch

BuildRequires: binutils cmake >= 2.8.11 gcc ninja-build
BuildRequires: /usr/bin/rst2man perl-generators python3-docutils
BuildRequires: libudev-devel valgrind-devel systemd systemd-devel
BuildRequires: pkgconfig(libnl-3.0) pkgconfig(libnl-route-3.0)
%if %{with pandoc}
BuildRequires: pandoc
%endif
%if %{with pyverbs}
BuildRequires: python3-Cython python3-devel
%else
BuildRequires: python3
%endif

Requires: pciutils
Provides: rdma = %{EVR}
Obsoletes: rdma < %{EVR}
Obsoletes: rdma-core < %{EVR}
Conflicts: infiniband-diags <= 1.6.7

%description
This is the userspace components for the Linux Kernel's drivers/infiniband subsystem.
Specifically this contains the userspace libraries for the following device nodes:

- /dev/infiniband/uverbsX (libibverbs)
- /dev/infiniband/rdma_cm (librdmacm)
- /dev/infiniband/umadX (libibumad)

Additional service daemons are provided for:

- srp_daemon (ib_srp.ko)
- iwpmd (for iwarp kernel providers)
- ibacm (for InfiniBand communication management assistant)

%package devel
Summary: Development libraries and headers for %{name}

%if %{with static}
BuildRequires: pkgconfig(libnl-3.0) pkgconfig(libnl-route-3.0)
%endif

Requires: libibverbs = %{EVR}
Requires: libibumad = %{EVR}
Requires: librdmacm = %{EVR}
Requires: infiniband-diags = %{EVR}

Provides: libibverbs-devel = %{EVR}
Provides: libibumad-devel = %{EVR}
Provides: librdmacm-devel = %{EVR}
Provides: ibacm-devel = %{EVR}
Provides: infiniband-diags-devel = %{EVR}
Provides: libibmad-devel = %{EVR}

Obsoletes: libibverbs-devel < %{EVR}
Obsoletes: libibumad-devel < %{EVR}
Obsoletes: librdmacm-devel < %{EVR}
Obsoletes: ibacm-devel < %{EVR}
Obsoletes: infiniband-diags-devel < %{EVR}
Obsoletes: libibmad-devel < %{EVR}

%description devel
RDMA core development libraries and headers.

%package -n libibverbs
Summary: A library and drivers for direct userspace use of RDMA (InfiniBand/iWARP/RoCE) hardware

Provides: libcxgb4 = %{EVR}
Provides: libefa = %{EVR}
Provides: libhfi1 = %{EVR}
Provides: libipathverbs = %{EVR}
Provides: libirdma = %{EVR}
Provides: libmlx4 = %{EVR}
Provides: libmlx5 = %{EVR}
Provides: libmthca = %{EVR}
Provides: libocrdma = %{EVR}
Provides: librxe = %{EVR}

Obsoletes: libcxgb4 < %{EVR}
Obsoletes: libefa < %{EVR}
Obsoletes: libhfi1 < %{EVR}
Obsoletes: libipathverbs < %{EVR}
Obsoletes: libirdma < %{EVR}
Obsoletes: libmlx4 < %{EVR}
Obsoletes: libmlx5 < %{EVR}
Obsoletes: libmthca < %{EVR}
Obsoletes: libocrdma < %{EVR}
Obsoletes: librxe < %{EVR}
Obsoletes: libibverbs-core < %{EVR}

%description -n libibverbs
libibverbs is a library that allows programs to use RDMA "verbs" for direct
access to RDMA (currently InfiniBand and iWARP) hardware from userspace.
For more information on RDMA verbs, see the InfiniBand Architecture Specification vol. 1,
especially chapter 11, and the RDMA Consortium's RDMA Protocol Verbs Specification.

Device-specific plug-in ibverbs userspace drivers are included:

- libcxgb4: Chelsio T4 iWARP HCA
- libefa: Amazon Elastic Fabric Adapter
- libhfi1: Intel Omni-Path HFI
- libhns: HiSilicon Hip06 SoC
- libipathverbs: QLogic InfiniPath HCA
- libirdma: Intel Ethernet Connection RDMA
- libmlx4: Mellanox ConnectX-3 InfiniBand HCA
- libmlx5: Mellanox Connect-IB/X-4+ InfiniBand HCA
- libmthca: Mellanox InfiniBand HCA
- libocrdma: Emulex OneConnect RDMA/RoCE Device
- libqedr: QLogic QL4xxx RoCE HCA
- librxe: A software implementation of the RoCE protocol
- libsiw: A software implementation of the iWarp protocol
- libvmw_pvrdma: VMware paravirtual RDMA device

%package -n libibumad
Summary: OpenFabrics Alliance InfiniBand umad (userspace management datagram) library

%description -n libibumad
libibumad provides the userspace management datagram (umad) library
functions, which sit on top of the umad modules in the kernel. These
are used by the IB diagnostic and management tools, including OpenSM.

%package -n librdmacm
Summary: Userspace RDMA Connection Manager

%description -n librdmacm
librdmacm provides a userspace RDMA Communication Management API.

%package -n ibacm
Summary: InfiniBand Communication Manager Assistant
%{?systemd_requires}

%description -n ibacm
The ibacm daemon helps reduce the load of managing path record lookups on
large InfiniBand fabrics by providing a user space implementation of what
is functionally similar to an ARP cache.  The use of ibacm, when properly
configured, can reduce the SA packet load of a large IB cluster from O(n^2)
to O(n).  The ibacm daemon is started and normally runs in the background,
user applications need not know about this daemon as long as their app
uses librdmacm to handle connection bring up/tear down.  The librdmacm
library knows how to talk directly to the ibacm daemon to retrieve data.

%package -n iwpmd
Summary: iWarp Port Mapper userspace daemon
%{?systemd_requires}

%description -n iwpmd
iwpmd provides a userspace service for iWarp drivers to claim
tcp ports through the standard socket interface.

%package -n librdmacm-utils
Summary: Examples for the librdmacm library
Requires: librdmacm = %{EVR}

%description -n librdmacm-utils
Example test programs for the librdmacm library.

%package -n libibverbs-utils
Summary: Examples for the libibverbs library
Requires: libibverbs = %{EVR}

%description -n libibverbs-utils
Useful libibverbs example programs such as ibv_devinfo, which
displays information about RDMA devices.

%package -n infiniband-diags
Summary: InfiniBand Diagnostic Tools
Requires: libibumad = %{EVR}

Provides: perl(IBswcountlimits)
Provides: libibmad = %{EVR}

Obsoletes: libibmad < %{EVR}
Obsoletes: openib-diags < 1.3

%description -n infiniband-diags
This package provides IB diagnostic programs and scripts needed to diagnose an
IB subnet and also provides libibmad now. libibmad provides low layer IB functions
for use by the IB diagnostic and management programs. These include MAD,
SA, SMP, and other basic IB functions.

%package -n infiniband-diags-compat
Summary: OpenFabrics Alliance InfiniBand Diagnostic Tools

%description -n infiniband-diags-compat
Deprecated scripts and utilities which provide duplicated functionality, most
often at a reduced performance.

%package -n srp_daemon
Summary: Tools for using the InfiniBand SRP protocol devices
Provides: srptools = %{EVR}

Obsoletes: srptools <= 1.0.3
Obsoletes: openib-srptools <= 0.0.6
%{?systemd_requires}

%description -n srp_daemon
In conjunction with the kernel ib_srp driver, srp_daemon allows you to
discover and use SCSI devices via the SCSI RDMA Protocol over InfiniBand.

%if %{with pyverbs}
%package -n python3-pyverbs
Summary: Python3 API over IB verbs

%description -n python3-pyverbs
Pyverbs provides a Python API over rdma-core, the Linux userspace C API for the RDMA stack.
%endif

%prep
%autosetup -p1

%build
%cmake -GNinja \
         -DCMAKE_BUILD_TYPE=Release \
         -DCMAKE_INSTALL_BINDIR:PATH=%{_bindir} \
         -DCMAKE_INSTALL_SBINDIR:PATH=%{_sbindir} \
         -DCMAKE_INSTALL_LIBDIR:PATH=%{_libdir} \
         -DCMAKE_INSTALL_LIBEXECDIR:PATH=%{_libexecdir} \
         -DCMAKE_INSTALL_LOCALSTATEDIR:PATH=%{_localstatedir} \
         -DCMAKE_INSTALL_SHAREDSTATEDIR:PATH=%{_sharedstatedir} \
         -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_includedir} \
         -DCMAKE_INSTALL_INFODIR:PATH=%{_infodir} \
         -DCMAKE_INSTALL_MANDIR:PATH=%{_mandir} \
         -DCMAKE_INSTALL_SYSCONFDIR:PATH=%{_sysconfdir} \
         -DCMAKE_INSTALL_SYSTEMD_SERVICEDIR:PATH=%{_unitdir} \
         -DCMAKE_INSTALL_INITDDIR:PATH=%{_initrddir} \
         -DCMAKE_INSTALL_RUNDIR:PATH=%{_rundir} \
         -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name} \
         -DCMAKE_INSTALL_UDEV_RULESDIR:PATH=%{_udevrulesdir} \
         -DCMAKE_INSTALL_PERLDIR:PATH=%{perl_vendorlib} \
         -DENABLE_IBDIAGS_COMPAT:BOOL=True \
         -DPYTHON_EXECUTABLE:PATH=%{__python3} \
         -DCMAKE_INSTALL_PYTHON_ARCH_LIB:PATH=%{python3_sitearch} \
%if %{with static}
         -DENABLE_STATIC=1 \
%endif
%if %{with pyverbs}
         -DNO_PYVERBS=0
%else
	 -DNO_PYVERBS=1
%endif

ninja-build -C %{_vpath_builddir} -v %{?_smp_mflags}

%install
DESTDIR=%{buildroot} ninja-build -C %{_vpath_builddir} install
rm -rf %{buildroot}/%{_initrddir}/
rm -f %{buildroot}/%{_sbindir}/srp_daemon.sh
rm -f %{buildroot}%{_sysconfdir}/rdma/modules/rdma.conf

mkdir -p %{buildroot}/%{_sysconfdir}/rdma %{buildroot}%{_libexecdir} %{buildroot}%{_udevrulesdir}
mkdir -p %{buildroot}%{_prefix}/lib/dracut/modules.d/05rdma %{buildroot}%{_modprobedir}
install -D -m0644 -p redhat/rdma.mlx4.conf %{buildroot}/%{_sysconfdir}/rdma/mlx4.conf
install -D -m0755 -p redhat/rdma.modules-setup.sh %{buildroot}%{_prefix}/lib/dracut/modules.d/05rdma/module-setup.sh
install -D -m0644 -p redhat/rdma.mlx4.sys.modprobe %{buildroot}%{_modprobedir}/libmlx4.conf
install -D -m0755 -p redhat/rdma.mlx4-setup.sh %{buildroot}%{_libexecdir}/mlx4-setup.sh
install -D -m0644 -p redhat/rdma.conf %{buildroot}%{_sysconfdir}/rdma/modules/rdma.conf

(if [ -d %{__cmake_builddir} ]; then cd %{__cmake_builddir}; fi
 ./bin/ib_acme -D . -O &&
 install -D -m0644 -p ibacm_opts.cfg %{buildroot}%{_sysconfdir}/rdma/)

%post -n rdma-core
if [ -x /sbin/udevadm ]; then
/sbin/udevadm trigger --subsystem-match=infiniband --action=change || true
/sbin/udevadm trigger --subsystem-match=net --action=change || true
/sbin/udevadm trigger --subsystem-match=infiniband_mad --action=change || true
fi

%post -n ibacm
%systemd_post ibacm.service
%preun -n ibacm
%systemd_preun ibacm.service
%postun -n ibacm
%systemd_postun_with_restart ibacm.service

%post -n srp_daemon
%systemd_post srp_daemon.service
%preun -n srp_daemon
%systemd_preun srp_daemon.service
%postun -n srp_daemon
%systemd_postun_with_restart srp_daemon.service

%post -n iwpmd
%systemd_post iwpmd.service
%preun -n iwpmd
%systemd_preun iwpmd.service
%postun -n iwpmd
%systemd_postun_with_restart iwpmd.service

%files
%dir %{_sysconfdir}/rdma
%config(noreplace) %{_sysconfdir}/rdma/mlx4.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/infiniband.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/iwarp.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/opa.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/rdma.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/roce.conf
%dir %{_sysconfdir}/modprobe.d
%config(noreplace) %{_sysconfdir}/modprobe.d/mlx4.conf
%config(noreplace) %{_sysconfdir}/modprobe.d/truescale.conf
%dir %{_modprobedir}
%{_modprobedir}/libmlx4.conf

%{_libexecdir}/mlx4-setup.sh
%{_libexecdir}/truescale-serdes.cmds
%{_sbindir}/rdma-ndd

%{_unitdir}/rdma-hw.target
%{_unitdir}/rdma-load-modules@.service
%{_unitdir}/rdma-ndd.service

%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%dir %{_prefix}/lib/dracut/modules.d/05rdma
%{_prefix}/lib/dracut/modules.d/05rdma/module-setup.sh

%dir %{_udevrulesdir}
%{_udevrulesdir}/../rdma_rename
%{_udevrulesdir}/60-rdma-ndd.rules
%{_udevrulesdir}/60-rdma-persistent-naming.rules
%{_udevrulesdir}/75-rdma-description.rules
%{_udevrulesdir}/90-rdma-hw-modules.rules
%{_udevrulesdir}/90-rdma-ulp-modules.rules
%{_udevrulesdir}/90-rdma-umad.rules

%{_mandir}/man7/rxe*.zst
%{_mandir}/man8/rdma-ndd.*.zst

%license COPYING.*
%doc README.md 70-persistent-ipoib.rules rxe.md udev.md tag_matching.md

%files devel
%if %{with static}
%{_libdir}/lib*.a
%endif
%{_libdir}/libefa.so
%{_libdir}/libibmad.so
%{_libdir}/libibnetdisc.so
%{_libdir}/libibumad.so
%{_libdir}/libibverbs.so
%{_libdir}/libmana.so
%{_libdir}/libmlx4.so
%{_libdir}/libmlx5.so
%{_libdir}/librdmacm.so
%{_libdir}/pkgconfig/lib*.pc

%dir %{_includedir}/infiniband
%dir %{_includedir}/rdma
%{_includedir}/infiniband/*.h
%{_includedir}/rdma/*.h

%{_mandir}/man3/efadv*.zst
%{_mandir}/man3/ibv_*.zst
%{_mandir}/man3/rdma*.zst
%{_mandir}/man3/umad*.zst
%{_mandir}/man3/*_to_ibv_rate.*.zst
%{_mandir}/man3/manadv*.zst
%{_mandir}/man3/mlx5dv*.zst
%{_mandir}/man3/mlx4dv*.zst
%{_mandir}/man3/ibnd_*.zst
%{_mandir}/man7/rdma_cm.*.zst
%{_mandir}/man7/efadv*.zst
%{_mandir}/man7/manadv*.zst
%{_mandir}/man7/mlx5dv*.zst
%{_mandir}/man7/mlx4dv*.zst
%doc %{_docdir}/%{name}/MAINTAINERS

%files -n libibverbs
%dir %{_sysconfdir}/libibverbs.d
%config(noreplace) %{_sysconfdir}/libibverbs.d/*.driver

%dir %{_libdir}/libibverbs
%{_libdir}/libefa.so.1
%{_libdir}/libefa.so.1.2.44.0
%{_libdir}/libibverbs.so.1
%{_libdir}/libibverbs.so.1.14.44.0
%{_libdir}/libibverbs/libbnxt_re-rdmav34.so
%{_libdir}/libibverbs/libcxgb4-rdmav34.so
%{_libdir}/libibverbs/libefa-rdmav34.so
%{_libdir}/libibverbs/liberdma-rdmav34.so
%{_libdir}/libibverbs/libhfi1verbs-rdmav34.so
%{_libdir}/libibverbs/libhns-rdmav34.so
%{_libdir}/libibverbs/libipathverbs-rdmav34.so
%{_libdir}/libibverbs/libirdma-rdmav34.so
%{_libdir}/libibverbs/libmana-rdmav34.so
%{_libdir}/libibverbs/libmlx4-rdmav34.so
%{_libdir}/libibverbs/libmlx5-rdmav34.so
%{_libdir}/libibverbs/libmthca-rdmav34.so
%{_libdir}/libibverbs/libocrdma-rdmav34.so
%{_libdir}/libibverbs/libqedr-rdmav34.so
%{_libdir}/libibverbs/librxe-rdmav34.so
%{_libdir}/libibverbs/libsiw-rdmav34.so
%{_libdir}/libibverbs/libvmw_pvrdma-rdmav34.so
%{_libdir}/libmana.so.1
%{_libdir}/libmana.so.1.0.44.0
%{_libdir}/libmlx4.so.1
%{_libdir}/libmlx4.so.1.0.44.0
%{_libdir}/libmlx5.so.1
%{_libdir}/libmlx5.so.1.24.44.0
%doc %{_docdir}/%{name}/libibverbs.md

%files -n libibumad
%{_libdir}/libibumad.so.3
%{_libdir}/libibumad.so.3.2.44.0

%files -n librdmacm
%dir %{_libdir}/rsocket
%{_libdir}/rsocket/librspreload.so
%{_libdir}/rsocket/librspreload.so.1
%{_libdir}/rsocket/librspreload.so.1.0.0
%{_libdir}/librdmacm.so.1
%{_libdir}/librdmacm.so.1.3.44.0
%{_mandir}/man7/rsocket.*.zst
%doc %{_docdir}/%{name}/librdmacm.md

%files -n ibacm
%config(noreplace) %{_sysconfdir}/rdma/ibacm_opts.cfg
%{_bindir}/ib_acme
%{_sbindir}/ibacm
%dir %{_libdir}/ibacm
%{_libdir}/ibacm/libibacmp.so
%{_unitdir}/ibacm.service
%{_unitdir}/ibacm.socket
%{_mandir}/man1/ib_acme.*.zst
%{_mandir}/man7/ibacm.*.zst
%{_mandir}/man7/ibacm_prov.*.zst
%{_mandir}/man8/ibacm.*.zst
%doc %{_docdir}/%{name}/ibacm.md

%files -n iwpmd
%config(noreplace) %{_sysconfdir}/rdma/modules/iwpmd.conf
%config(noreplace) %{_sysconfdir}/iwpmd.conf
%{_sbindir}/iwpmd
%{_unitdir}/iwpmd.service
%{_udevrulesdir}/90-iwpmd.rules
%{_mandir}/man8/iwpmd.*.zst
%{_mandir}/man5/iwpmd.*.zst

%files -n librdmacm-utils
%{_bindir}/cmtime
%{_bindir}/mckey
%{_bindir}/rcopy
%{_bindir}/rdma_client
%{_bindir}/rdma_server
%{_bindir}/rdma_xclient
%{_bindir}/rdma_xserver
%{_bindir}/riostream
%{_bindir}/rping
%{_bindir}/rstream
%{_bindir}/ucmatose
%{_bindir}/udaddy
%{_bindir}/udpong
%{_mandir}/man1/cmtime.*.zst
%{_mandir}/man1/mckey.*.zst
%{_mandir}/man1/rcopy.*.zst
%{_mandir}/man1/rdma_client.*.zst
%{_mandir}/man1/rdma_server.*.zst
%{_mandir}/man1/rdma_xclient.*.zst
%{_mandir}/man1/rdma_xserver.*.zst
%{_mandir}/man1/riostream.*.zst
%{_mandir}/man1/rping.*.zst
%{_mandir}/man1/rstream.*.zst
%{_mandir}/man1/ucmatose.*.zst
%{_mandir}/man1/udaddy.*.zst
%{_mandir}/man1/udpong.*.zst

%files -n libibverbs-utils
%{_bindir}/ibv_asyncwatch
%{_bindir}/ibv_devices
%{_bindir}/ibv_devinfo
%{_bindir}/ibv_rc_pingpong
%{_bindir}/ibv_srq_pingpong
%{_bindir}/ibv_uc_pingpong
%{_bindir}/ibv_ud_pingpong
%{_bindir}/ibv_xsrq_pingpong
%{_mandir}/man1/ibv_*.zst

%files -n infiniband-diags
%config(noreplace) %{_sysconfdir}/infiniband-diags/error_thresholds
%config(noreplace) %{_sysconfdir}/infiniband-diags/ibdiag.conf
%{_sbindir}/check_lft_balance.pl
%{_sbindir}/dump_fts
%{_sbindir}/dump_lfts.sh
%{_sbindir}/dump_mfts.sh
%{_sbindir}/ibaddr
%{_sbindir}/ibcacheedit
%{_sbindir}/ibccconfig
%{_sbindir}/ibccquery
%{_sbindir}/ibclearcounters
%{_sbindir}/ibclearerrors
%{_sbindir}/ibfindnodesusing.pl
%{_sbindir}/ibhosts
%{_sbindir}/ibidsverify.pl
%{_sbindir}/iblinkinfo
%{_sbindir}/ibnetdiscover
%{_sbindir}/ibnodes
%{_sbindir}/ibping
%{_sbindir}/ibportstate
%{_sbindir}/ibqueryerrors
%{_sbindir}/ibroute
%{_sbindir}/ibrouters
%{_sbindir}/ibstat
%{_sbindir}/ibstatus
%{_sbindir}/ibswitches
%{_sbindir}/ibsysstat
%{_sbindir}/ibtracert
%{_sbindir}/perfquery
%{_sbindir}/saquery
%{_sbindir}/sminfo
%{_sbindir}/smpdump
%{_sbindir}/smpquery
%{_sbindir}/vendstat
%{_libdir}/libibmad.so.5
%{_libdir}/libibmad.so.5.3.44.0
%{_libdir}/libibnetdisc.so.5
%{_libdir}/libibnetdisc.so.5.0.44.0
%{perl_vendorlib}/IBswcountlimits.pm
%{_mandir}/man8/check_lft_balance*.zst
%{_mandir}/man8/dump_fts*.zst
%{_mandir}/man8/dump_lfts*.zst
%{_mandir}/man8/dump_mfts*.zst
%{_mandir}/man8/ibaddr*.zst
%{_mandir}/man8/ibcacheedit*.zst
%{_mandir}/man8/ibccconfig*.zst
%{_mandir}/man8/ibccquery*.zst
%{_mandir}/man8/ibclearcounters*.zst
%{_mandir}/man8/ibclearerrors*.zst
%{_mandir}/man8/ibfindnodesusing*.zst
%{_mandir}/man8/ibhosts*.zst
%{_mandir}/man8/ibidsverify*.zst
%{_mandir}/man8/iblinkinfo*.zst
%{_mandir}/man8/ibnetdiscover*.zst
%{_mandir}/man8/ibnodes*.zst
%{_mandir}/man8/ibping*.zst
%{_mandir}/man8/ibportstate*.zst
%{_mandir}/man8/ibqueryerrors*.zst
%{_mandir}/man8/ibroute.*.zst
%{_mandir}/man8/ibrouters*.zst
%{_mandir}/man8/ibstat.*.zst
%{_mandir}/man8/ibswitches*.zst
%{_mandir}/man8/ibsysstat*.zst
%{_mandir}/man8/ibtracert*.zst
%{_mandir}/man8/perfquery*.zst
%{_mandir}/man8/saquery*.zst
%{_mandir}/man8/sminfo*.zst
%{_mandir}/man8/smpdump*.zst
%{_mandir}/man8/smpquery*.zst
%{_mandir}/man8/vendstat*.zst
%{_mandir}/man8/ibstatus*.zst
%{_mandir}/man8/infiniband-diags*.zst

%files -n infiniband-diags-compat
%{_sbindir}/ibcheckerrs
%{_sbindir}/ibchecknet
%{_sbindir}/ibchecknode
%{_sbindir}/ibcheckport
%{_sbindir}/ibcheckportwidth
%{_sbindir}/ibcheckportstate
%{_sbindir}/ibcheckwidth
%{_sbindir}/ibcheckstate
%{_sbindir}/ibcheckerrors
%{_sbindir}/ibdatacounts
%{_sbindir}/ibdatacounters
%{_sbindir}/ibdiscover.pl
%{_sbindir}/ibswportwatch.pl
%{_sbindir}/ibqueryerrors.pl
%{_sbindir}/iblinkinfo.pl
%{_sbindir}/ibprintca.pl
%{_sbindir}/ibprintswitch.pl
%{_sbindir}/ibprintrt.pl
%{_sbindir}/set_nodedesc.sh
%{_mandir}/man8/ibcheckerrs*.zst
%{_mandir}/man8/ibchecknet*.zst
%{_mandir}/man8/ibchecknode*.zst
%{_mandir}/man8/ibcheckport.*.zst
%{_mandir}/man8/ibcheckportwidth*.zst
%{_mandir}/man8/ibcheckportstate*.zst
%{_mandir}/man8/ibcheckwidth*.zst
%{_mandir}/man8/ibcheckstate*.zst
%{_mandir}/man8/ibcheckerrors*.zst
%{_mandir}/man8/ibdatacounts*.zst
%{_mandir}/man8/ibdatacounters*.zst
%{_mandir}/man8/ibdiscover*.zst
%{_mandir}/man8/ibswportwatch*.zst
%{_mandir}/man8/ibprintca*.zst
%{_mandir}/man8/ibprintswitch*.zst
%{_mandir}/man8/ibprintrt*.zst

%files -n srp_daemon
%config(noreplace) %{_sysconfdir}/srp_daemon.conf
%config(noreplace) %{_sysconfdir}/rdma/modules/srp_daemon.conf
%{_sbindir}/ibsrpdm
%{_sbindir}/srp_daemon
%{_sbindir}/run_srp_daemon
%{_libexecdir}/srp_daemon/start_on_all_ports
%{_unitdir}/srp_daemon.service
%{_unitdir}/srp_daemon_port@.service
%{_udevrulesdir}/60-srp_daemon.rules
%{_mandir}/man5/srp_daemon.service.5*.zst
%{_mandir}/man5/srp_daemon_port@.service.5*.zst
%{_mandir}/man8/ibsrpdm.8*.zst
%{_mandir}/man8/srp_daemon.8*.zst
%doc %{_docdir}/%{name}/ibsrpdm.md

%if %{with pyverbs}
%files -n python3-pyverbs
%{python3_sitearch}/pyverbs
%{_docdir}/%{name}/tests/*.py
%endif

%changelog
* Mon Mar 11 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 44.0-4
- Rebuild with python3.11

* Mon Apr 10 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 44.0-3
- Refactor the specfile

* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 44.0-2
- disable pandoc

* Fri Mar 10 2023 Funda Wang <fundawang@yeah.net> - 44.0-1
- New version 44.0

* Sun Jan 1 2023 Funda Wang <fundawang@yeah.net> - 42.1-1
- New version 42.1

* Tue Mar 08 2022 Jacob Wang <yungao.jacob@linux.alibaba.com> - 39.0-1
- Initial version from upstream 39.0
